import dedent from 'dedent-js';

import { format as originalFormat, FormatFn } from 'src/sqlFormatter';
import SqlFormatter from 'src/languages/sql.formatter';
import behavesLikeSqlFormatter from './behavesLikeSqlFormatter';

import supportsCreateTable from './features/createTable';
import supportsAlterTable from './features/alterTable';
import supportsSchema from './features/schema';
import supportsStrings from './features/strings';
import supportsBetween from './features/between';
import supportsJoin from './features/join';
import supportsOperators from './features/operators';
import supportsConstraints from './features/constraints';
import supportsDeleteFrom from './features/deleteFrom';
import supportsComments from './features/comments';
import supportsParams from './options/param';

describe('SqlFormatter', () => {
  const language = 'sql';
  const format: FormatFn = (query, cfg = {}) => originalFormat(query, { ...cfg, language });

  behavesLikeSqlFormatter(format);
  supportsComments(format);
  supportsCreateTable(format);
  supportsConstraints(format);
  supportsAlterTable(format);
  supportsDeleteFrom(format);
  supportsStrings(format, SqlFormatter.stringTypes);
  supportsBetween(format);
  supportsSchema(format);
  supportsJoin(format);
  supportsOperators(format, SqlFormatter.operators);
  supportsParams(format, { indexed: ['?'] });

  it('formats FETCH FIRST like LIMIT', () => {
    const result = format('SELECT * FETCH FIRST 2 ROWS ONLY;');
    expect(result).toBe(dedent`
      SELECT
        *
      FETCH FIRST
        2 ROWS ONLY;
    `);
  });

  // This is a crappy behavior, but at least we don't crash
  it('does not crash when encountering characters or operators it does not recognize', () => {
    expect(
      format(`
        SELECT @name, :bar FROM {foo};
      `)
    ).toBe(dedent`
      SELECT
        @ name,
      : bar
      FROM
      {foo};
    `);
  });
});
